@@ -106,6 +106,14 @@ if you would like to continue with the index creation.
 This option will print out the table information to the 
 config file that you specified.
 
+=head3 --debugpath FILE
+
+This option prints out the path information for debugging 
+purposes. This option is only really available with the 
+--reatime option because otherwise the path information is 
+stored in the database. You can get this information in a 
+file if you use the --verbose option while creating the index. 
+
 =head3 --cuilist FILE
 
 This option takes in a file containing a list of CUIs (one CUI 
@@ -183,8 +191,8 @@ this program; if not, write to:
 
 use UMLS::Interface;
 use Getopt::Long;
-
-GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "forcerun", "debug", "verbose", "cuilist=s", "realtime", "minimum", "maximum", "infile=s");
+# catch, abort and print the message for unknown options specified
+eval(GetOptions( "version", "help", "username=s", "password=s", "hostname=s", "database=s", "socket=s", "config=s", "forcerun", "debug", "verbose", "debugpath=s", "cuilist=s", "realtime", "minimum", "maximum", "infile=s")) or die ("Please check the above mentioned option(s).\n");
 
 
 #  if help is defined, print out help
@@ -234,6 +242,9 @@ if(defined $opt_debug) {
 if(defined $opt_verbose) {
     $option_hash{"verbose"} = $opt_verbose;
 }
+if(defined $opt_debugpath) {
+    $option_hash{"debugpath"} = $opt_debugpath;
+}
 if(defined $opt_cuilist) {
     $option_hash{"cuilist"} = $opt_cuilist;
 }
@@ -403,7 +414,10 @@ sub showHelp() {
     print "                         like to continue with the index \n";
     print "                         creation. \n\n";
 
-    print "--verbose                This option prints out the path information\n";
+    print "--debugpath FILE         This option prints out the path\n";
+    print "                         information for debugging purposes\n\n";
+  
+    print "--verbose                This option prints out the table information to the specified config directory\n";
     print "                         to a file in your config directory.\n\n";    
     print "--cuilist FILE           This option takes in a file containing a \n";
     print "                         list of CUIs (one CUI per line) and stores\n";
@@ -419,7 +433,7 @@ sub showHelp() {
 #  function to output the version number
 ##############################################################################
 sub showVersion {
-    print '$Id: findCuiDepth.pl,v 1.5 2010/03/31 19:38:00 btmcinnes Exp $';
+    print '$Id: findCuiDepth.pl,v 1.7 2010/04/17 18:39:12 btmcinnes Exp $';
     print "\nCopyright (c) 2008, Ted Pedersen & Bridget McInnes\n";
 }
 
